jupyterlab_widgets: Jupyter interactive widgets for JupyterLab
==============================================================

Description
-----------

Jupyter interactive widgets for JupyterLab

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/jupyterlab-widgets/

